# Copyright (C) 2018 NTT DATA
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from unittest import mock

from openstack_dashboard.test import helpers

from masakaridashboard.test.test_data import utils


class MasakariTestsMixin(object):
    def _setup_test_data(self):
        super(MasakariTestsMixin, self)._setup_test_data()
        utils.load_test_data(self)


class TestCase(MasakariTestsMixin, helpers.TestCase):

    def setUp(self):
        allowed_patch = mock.patch(
            "masakaridashboard.dashboard.MasakariDashboard.allowed",
            return_value=True)
        allowed_patch.start()
        self.addCleanup(mock.patch.stopall)
        super().setUp()
